@@ -11,10 +11,10 @@ use warnings;
 use English qw/ -no_match_vars /;
 use Path::Tiny;
 
-our $VERSION = 0.001;
+our $VERSION = 0.02;
 
 sub branch {
-    my ($self) = @_;
+    my ($self, $options) = @_;
     my ($type, $branch);
     my $dir = eval { path('.')->realpath };
     my $git = git();
@@ -51,6 +51,9 @@ sub branch {
     $type = $self->cols && $self->cols > 40 ? "$type " : '';
 
     my $max_branch_width = ( $self->cols || 80 ) / 3;
+    if ($max_branch_width > 60) {
+        $max_branch_width = 60;
+    }
     if ( length $branch > $max_branch_width ) {
         $branch = substr $branch, 0, $max_branch_width;
         $branch .= '...';
@@ -87,7 +90,7 @@ App::PS1::Plugin::Branch - Adds the current branch to prompt
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Branch version 0.001.
+This documentation refers to App::PS1::Plugin::Branch version 0.02.
 
 =head1 SYNOPSIS
 
